@@ -31,12 +31,20 @@ http_handler::http_handler()
     connect (networkAccessManager, SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)), this, SLOT(handleSSLError(QNetworkReply*,QList<QSslError>)));
 }
 
+void http_handler::applyRequestDefaults(QNetworkRequest* request)
+{
+    request->setRawHeader("user-agent", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Safari/537.36");
+    request->setRawHeader("cache-control", "no-cache");
+    request->setRawHeader("accept", "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9");
+    request->setRawHeader("pragma", "no-cache");
+}
+
 //Create a new QNetworkRequest
 QNetworkRequest http_handler::createRequest(QUrl url)
 {
     QNetworkRequest request;
     request.setUrl(url);
-    request.setRawHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
+    applyRequestDefaults(&request);
 
     return request;
 }
